package
Version:
v0.0.26
Opens a new window with list of versions in this module.
Published: Apr 6, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
type Debuger interface {
Debugf(string, ...interface{})
Debug(...interface{})
}
type Errorer interface {
Errorf(string, ...interface{})
Error(...interface{})
}
type Informer interface {
Infof(string, ...interface{})
Info(...interface{})
}
const (
Panic Level = iota
Error
Warn
Info
Debug
)
Logger : General slog interface for any implementation.
type Panicer interface {
Panicf(string, ...interface{})
Panic(...interface{})
}
type Printer interface {
Printf(string, ...interface{})
Print(...interface{})
}
type Warner interface {
Warnf(string, ...interface{})
Warn(...interface{})
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.